@@ -33,8 +33,7 @@
    build host when cross-compiling */
 char *prog_name = "mkdoc";
 #include "strrstr.c"
-#include "vasprintf.c"
-#include "zmalloc.c"
+#include "xalloc.c"
 #include "astr.c"
 
 struct fentry
@@ -177,7 +176,7 @@ process_file (char *filename)
 }
 
 /*
- * Stub to make zmalloc &c. happy.
+ * Stub to make xalloc_die happy.
  */
 void
 zile_exit (int doabort GCC_UNUSED)
