@@ -290,12 +290,10 @@ void set_current_window (Window * wp);
 void delete_window (Window * del_wp);
 Point window_pt (Window * wp);
 
-/* zmalloc.c -------------------------------------------------------------- */
-void *zmalloc (size_t size);
-void *zrealloc (void *ptr, size_t size);
-char *zstrdup (const char *s);
-int zvasprintf (char **ptr, const char *fmt, va_list vargs);
-int zasprintf (char **ptr, const char *fmt, ...);
+/* xalloc.c --------------------------------------------------------------- */
+#include "xalloc.h"
+int xvasprintf (char **ptr, const char *fmt, va_list vargs);
+int xasprintf (char **ptr, const char *fmt, ...);
 
 
 /*
