@@ -37,10 +37,10 @@ vector *leRoot;
 le *
 leNew (const char *text)
 {
-  le *new = (le *) zmalloc (sizeof (le));
+  le *new = (le *) xzalloc (sizeof (le));
 
   new->branch = NULL;
-  new->data = text ? zstrdup (text) : NULL;
+  new->data = text ? xstrdup (text) : NULL;
   new->quoted = 0;
   new->tag = -1;
   new->list_prev = NULL;
@@ -192,7 +192,7 @@ leTagReplace (le * list, int tagval, le * newinfo)
 	      list->quoted = 1;
 	    }
 	  else if (newinfo->data)
-	    list->data = zstrdup (newinfo->data);
+	    list->data = xstrdup (newinfo->data);
 	}
       leTagReplace (list->branch, tagval, newinfo);
 
@@ -247,7 +247,7 @@ leDumpEval (le * list, int indent GCC_UNUSED)
 astr
 leDumpReformat (le * tree)
 {
-  int notfirst = FALSE;
+  int notfirst = false;
   astr as = astr_new ();
 
   if (tree)
@@ -259,7 +259,7 @@ leDumpReformat (le * tree)
 	  if (tree->data)
 	    {
 	      astr_afmt (as, "%s%s", notfirst ? " " : "", tree->data);
-	      notfirst = TRUE;
+	      notfirst = true;
 	    }
 
 	  if (tree->branch)
