@@ -48,7 +48,7 @@ macro_delete (Macro * mp)
 static void
 add_macro_key (Macro * mp, size_t key)
 {
-  mp->keys = zrealloc (mp->keys, sizeof (size_t) * ++mp->nkeys);
+  mp->keys = xrealloc (mp->keys, sizeof (size_t) * ++mp->nkeys);
   mp->keys[mp->nkeys - 1] = key;
 }
 
@@ -67,7 +67,7 @@ void
 add_key_to_cmd (size_t key)
 {
   if (cmd_mp == NULL)
-    cmd_mp = zmalloc (sizeof (Macro));
+    cmd_mp = xzalloc (sizeof (Macro));
 
   add_macro_key (cmd_mp, key);
 }
@@ -92,7 +92,7 @@ Use M-x name-last-kbd-macro to give it a permanent name.
   if (thisflag & FLAG_DEFINING_MACRO)
     {
       minibuf_error ("Already defining a keyboard macro");
-      return FALSE;
+      return false;
     }
 
   if (cur_mp)
@@ -101,8 +101,8 @@ Use M-x name-last-kbd-macro to give it a permanent name.
   minibuf_write ("Defining keyboard macro...");
 
   thisflag |= FLAG_DEFINING_MACRO;
-  cur_mp = zmalloc (sizeof (Macro));
-  return TRUE;
+  cur_mp = xzalloc (sizeof (Macro));
+  return true;
 }
 END_DEFUN
 
@@ -116,11 +116,11 @@ The macro is now available for use via C-x e.
   if (!(thisflag & FLAG_DEFINING_MACRO))
     {
       minibuf_error ("Not defining a keyboard macro");
-      return FALSE;
+      return false;
     }
 
   thisflag &= ~FLAG_DEFINING_MACRO;
-  return TRUE;
+  return true;
 }
 END_DEFUN
 
@@ -139,13 +139,13 @@ Such a "function" cannot be called from Lisp, but it is a valid editor command.
   if (ms == NULL)
     {
       minibuf_error ("No command name given");
-      return FALSE;
+      return false;
     }
 
   if (cur_mp == NULL)
     {
       minibuf_error ("No keyboard macro defined");
-      return FALSE;
+      return false;
     }
 
   mp = get_macro (ms);
@@ -157,19 +157,19 @@ Such a "function" cannot be called from Lisp, but it is a valid editor command.
   else
     {
       /* Add a new macro to the list */
-      mp = zmalloc (sizeof (*mp));
+      mp = xzalloc (sizeof (*mp));
       mp->next = head_mp;
-      mp->name = zstrdup (ms);
+      mp->name = xstrdup (ms);
       head_mp = mp;
     }
 
   /* Copy the keystrokes from cur_mp. */
   mp->nkeys = cur_mp->nkeys;
   size = sizeof (*(mp->keys)) * mp->nkeys;
-  mp->keys = zmalloc (size);
+  mp->keys = xzalloc (size);
   memcpy (mp->keys, cur_mp->keys, size);
 
-  return TRUE;
+  return true;
 }
 END_DEFUN
 
@@ -193,12 +193,12 @@ To make a macro permanent so you can call it even after
 defining others, use M-x name-last-kbd-macro.
 +*/
 {
-  int uni, ret = TRUE;
+  int uni, ret = true;
 
   if (cur_mp == NULL)
     {
       minibuf_error ("No kbd macro has been defined");
-      return FALSE;
+      return false;
     }
 
   undo_save (UNDO_START_SEQUENCE, cur_bp->pt, 0, 0);
