@@ -31,14 +31,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if HAVE_UNISTD_H
 #include <unistd.h>
-#endif
-#if HAVE_GETOPT_LONG_ONLY
 #include <getopt.h>
-#else
-#include "getopt.h"
-#endif
 #include <signal.h>
 #if HAVE_LIBGEN_H
 #include <libgen.h>
@@ -175,7 +169,7 @@ setup_main_screen (int argc)
     {
       if (argc < 1)
         {
-          undo_nosave = TRUE;
+          undo_nosave = true;
 
           if (!lookup_bool_variable ("inhibit-splash-screen"))
             insert_string ("\
@@ -184,7 +178,7 @@ If you want to create a file, visit that file with C-x C-f,\n\
 then enter the text in that file's own buffer.\n\
 \n");
 
-          undo_nosave = FALSE;
+          undo_nosave = false;
           cur_bp->flags &= ~BFLAG_MODIFIED;
           lastflag |= FLAG_NEED_RESYNC;
         }
@@ -199,7 +193,7 @@ segv_sig_handler (int signo GCC_UNUSED)
            " crashed.  Please send a bug report to <"
            PACKAGE_BUGREPORT ">.\r\n",
            prog_name);
-  zile_exit (TRUE);
+  zile_exit (true);
 }
 
 static void
@@ -207,7 +201,7 @@ other_sig_handler (int signo GCC_UNUSED)
 {
   fprintf (stderr, "%s: terminated with signal %d.\r\n",
            prog_name, signo);
-  zile_exit (FALSE);
+  zile_exit (false);
 }
 
 static void
@@ -237,15 +231,15 @@ struct option longopts[] = {
 int
 main (int argc, char **argv)
 {
-  int c, bflag = FALSE, qflag = FALSE;
+  int c, bflag = false, qflag = false;
   list fargs = list_new ();
   size_t line;
 
   /* Set prog_name to executable name, if available */
 #if HAVE_BASENAME
   if (argv[0]) {
-    char *s = zstrdup (argv[0]);
-    prog_name = zstrdup (basename (s));
+    char *s = xstrdup (argv[0]);
+    prog_name = xstrdup (basename (s));
     free (s);
   }
 #endif
@@ -257,7 +251,7 @@ main (int argc, char **argv)
   init_variables ();
 
   opterr = 0;			/* Don't display errors for unknown options */
-  while (TRUE)
+  while (true)
     {
       int this_optind = optind ? optind : 1;
 
@@ -270,14 +264,14 @@ main (int argc, char **argv)
       switch (c)
         {
         case 'b':
-          bflag = TRUE;
-          qflag = TRUE;
+          bflag = true;
+          qflag = true;
           break;
         case 'f':
           list_append (fargs, optarg);
           break;
         case 'q':
-          qflag = TRUE;
+          qflag = true;
           break;
         case 'v':
           fprintf (stdout,
@@ -378,7 +372,7 @@ main (int argc, char **argv)
          written during startup */
       if (minibuf_contents != NULL)
         {
-          char *buf = zstrdup (minibuf_contents);
+          char *buf = xstrdup (minibuf_contents);
 
           minibuf_write (buf);
           free (buf);
