@@ -52,7 +52,7 @@ minibuf_vwrite (const char *fmt, va_list ap)
   if (minibuf_contents != NULL)
     free (minibuf_contents);
 
-  zvasprintf (&minibuf_contents, fmt, ap);
+  xvasprintf (&minibuf_contents, fmt, ap);
 
   if (cur_wp)
     {
@@ -102,7 +102,7 @@ minibuf_read (const char *fmt, const char *value, ...)
   char *buf, *p;
 
   va_start (ap, value);
-  zvasprintf (&buf, fmt, ap);
+  xvasprintf (&buf, fmt, ap);
   va_end (ap);
 
   p = term_minibuf_read (buf, value ? value : "", NULL, NULL);
@@ -124,14 +124,14 @@ minibuf_read_dir (const char *fmt, const char *value, ...)
   astr as, rbuf;
 
   va_start (ap, value);
-  zvasprintf (&buf, fmt, ap);
+  xvasprintf (&buf, fmt, ap);
   va_end (ap);
 
   as = expand_path (astr_new_cstr (value));	/* Guaranteed to work */
   rbuf = compact_path (as);
   astr_delete (as);
 
-  cp = completion_new (TRUE);
+  cp = completion_new (true);
   p = term_minibuf_read (buf, astr_cstr (rbuf), cp, &files_history);
   free_completion (cp);
   astr_delete (rbuf);
@@ -143,7 +143,7 @@ minibuf_read_dir (const char *fmt, const char *value, ...)
       add_history_element (&files_history, p);
 
       rbuf = expand_path (astr_new_cstr (p));	/* Guaranteed to work */
-      p = zstrdup (astr_cstr (rbuf));
+      p = xstrdup (astr_cstr (rbuf));
       astr_delete (rbuf);
     }
 
@@ -158,7 +158,7 @@ minibuf_read_forced (const char *fmt, const char *errmsg,
   char *buf, *p;
 
   va_start (ap, cp);
-  zvasprintf (&buf, fmt, ap);
+  xvasprintf (&buf, fmt, ap);
   va_end (ap);
 
   for (;;)
@@ -177,7 +177,7 @@ minibuf_read_forced (const char *fmt, const char *errmsg,
 
 	  /* Complete partial words if possible. */
 	  astr_cpy_cstr (as, p);
-	  if (completion_try (cp, as, FALSE) == COMPLETION_MATCHED)
+	  if (completion_try (cp, as, false) == COMPLETION_MATCHED)
 	    p = cp->match;
 	  astr_delete (as);
 
@@ -195,7 +195,7 @@ minibuf_read_forced (const char *fmt, const char *errmsg,
     }
 
   assert (0);
-  return FALSE;
+  return false;
 }
 
 int
@@ -207,12 +207,12 @@ minibuf_read_yesno (const char *fmt, ...)
   int retvalue;
 
   va_start (ap, fmt);
-  zvasprintf (&buf, fmt, ap);
+  xvasprintf (&buf, fmt, ap);
   va_end (ap);
 
-  cp = completion_new (FALSE);
-  list_append (cp->completions, zstrdup ("yes"));
-  list_append (cp->completions, zstrdup ("no"));
+  cp = completion_new (false);
+  list_append (cp->completions, xstrdup ("yes"));
+  list_append (cp->completions, xstrdup ("no"));
 
   retvalue = minibuf_read_forced (buf, "Please answer yes or no.", cp);
   if (retvalue != -1)
@@ -220,9 +220,9 @@ minibuf_read_yesno (const char *fmt, ...)
       /* The completions may be sorted by the minibuf completion
 	 routines. */
       if (!strcmp (list_at (cp->completions, (size_t) retvalue), "yes"))
-	retvalue = TRUE;
+	retvalue = true;
       else
-	retvalue = FALSE;
+	retvalue = false;
     }
   free_completion (cp);
   free (buf);
@@ -241,7 +241,7 @@ minibuf_read_completion (const char *fmt, char *value, Completion * cp,
   char *buf, *p;
 
   va_start (ap, hp);
-  zvasprintf (&buf, fmt, ap);
+  xvasprintf (&buf, fmt, ap);
   va_end (ap);
 
   p = term_minibuf_read (buf, value, cp, hp);
