@@ -32,7 +32,7 @@
 #include "config.h"
 #include "extern.h"
 
-static int initted = FALSE;
+static int initted = false;
 static size_t width = 0, height = 0;
 static size_t cur_tab_width;
 static size_t cur_topline;
@@ -47,7 +47,7 @@ term_initted (void)
 void
 term_set_initted (void)
 {
-  initted = TRUE;
+  initted = true;
 }
 
 size_t
@@ -73,11 +73,11 @@ static int
 make_char_printable (char **buf, size_t c)
 {
   if (c == '\0')
-    return zasprintf (buf, "^@");
+    return xasprintf (buf, "^@");
   else if (c <= '\32')
-    return zasprintf (buf, "^%c", 'A' + c - 1);
+    return xasprintf (buf, "^%c", 'A' + c - 1);
   else
-    return zasprintf (buf, "\\%o", c & 0xff);
+    return xasprintf (buf, "\\%o", c & 0xff);
 }
 
 static void
@@ -116,25 +116,25 @@ in_region (size_t lineno, size_t x, Region * r)
       if (r->start.n == r->end.n)
 	{
 	  if (x >= r->start.o && x < r->end.o)
-	    return TRUE;
+	    return true;
 	}
       else if (lineno == r->start.n)
 	{
 	  if (x >= r->start.o)
-	    return TRUE;
+	    return true;
 	}
       else if (lineno == r->end.n)
 	{
 	  if (x < r->end.o)
-	    return TRUE;
+	    return true;
 	}
       else
 	{
-	  return TRUE;
+	  return true;
 	}
     }
 
-  return FALSE;
+  return false;
 }
 
 static void
@@ -185,11 +185,11 @@ calculate_highlight_region (Window * wp, Region * r, int *highlight)
       || (!transient_mark_mode ())
       || (transient_mark_mode () && !(wp->bp->mark_active)))
     {
-      *highlight = FALSE;
+      *highlight = false;
       return;
     }
 
-  *highlight = TRUE;
+  *highlight = true;
   r->start = window_pt (wp);
   r->end = wp->bp->mark->pt;
   if (cmp_point (r->end, r->start) < 0)
@@ -312,13 +312,13 @@ make_screen_pos (Window * wp, char **buf)
   Point pt = window_pt (wp);
 
   if (wp->bp->num_lines <= wp->eheight && wp->topdelta == pt.n)
-    zasprintf (buf, "All");
+    xasprintf (buf, "All");
   else if (pt.n == wp->topdelta)
-    zasprintf (buf, "Top");
+    xasprintf (buf, "Top");
   else if (pt.n + (wp->eheight - wp->topdelta) > wp->bp->num_lines)
-    zasprintf (buf, "Bot");
+    xasprintf (buf, "Bot");
   else
-    zasprintf (buf, "%2d%%", (int) ((float) pt.n / wp->bp->num_lines * 100));
+    xasprintf (buf, "%2d%%", (int) ((float) pt.n / wp->bp->num_lines * 100));
 
   return *buf;
 }
@@ -362,7 +362,7 @@ draw_status_line (size_t line, Window * wp)
     astr_cat_cstr (as, " Isearch");
 
   astr_cat_char (as, ')');
-  term_addnstr (astr_cstr (as), min (term_width (), astr_len (as)));
+  term_addnstr (astr_cstr (as), MIN (term_width (), astr_len (as)));
   astr_delete (as);
 
   term_attrset (1, FONT_NORMAL);
