@@ -25,7 +25,9 @@
 #define ZILE_H
 
 #include <stdlib.h>
+#include <stdbool.h>
 #include <limits.h>
+#include "minmax.h"
 
 #include "list.h"
 #include "astr.h"
@@ -33,16 +35,6 @@
 #include "parser.h"
 #include "eval.h"
 
-#undef TRUE
-#define TRUE                            1
-#undef FALSE
-#define FALSE                           0
-
-#undef min
-#define min(a, b)                       ((a) < (b) ? (a) : (b))
-#undef max
-#define max(a, b)                       ((a) > (b) ? (a) : (b))
-
 /*--------------------------------------------------------------------------
  * Main editor structures.
  *--------------------------------------------------------------------------*/
